Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(448)

Unified Diff: ppapi/c/private/pp_content_decryptor.h

Issue 11087044: Generalize Pepper CDM API decrypt and decode. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/c/private/pp_content_decryptor.h
diff --git a/ppapi/c/private/pp_content_decryptor.h b/ppapi/c/private/pp_content_decryptor.h
index 8467e9f90f8899a3550ca4f2c70f4ca1656f9f4d..c532c6c02cb1c7c92855f84b5c3abd2dcfee3e45 100644
--- a/ppapi/c/private/pp_content_decryptor.h
+++ b/ppapi/c/private/pp_content_decryptor.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* From private/pp_content_decryptor.idl modified Wed Oct 3 16:16:49 2012. */
+/* From private/pp_content_decryptor.idl modified Tue Oct 09 22:37:49 2012. */
#ifndef PPAPI_C_PRIVATE_PP_CONTENT_DECRYPTOR_H_
#define PPAPI_C_PRIVATE_PP_CONTENT_DECRYPTOR_H_
@@ -129,24 +129,14 @@ PP_COMPILE_ASSERT_STRUCT_SIZE_IN_BYTES(PP_EncryptedBlockInfo, 240);
* @{
*/
/**
- * <code>PP_DecryptedFrameFormat</code> contains video frame formats.
+ * <code>PP_StreamType</code> contains stream type constants.
*/
typedef enum {
- PP_DECRYPTEDFRAMEFORMAT_UNKNOWN = 0,
- PP_DECRYPTEDFRAMEFORMAT_EMPTY = 1,
- PP_DECRYPTEDFRAMEFORMAT_YV12 = 2,
- PP_DECRYPTEDFRAMEFORMAT_I420 = 3
-} PP_DecryptedFrameFormat;
-PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_DecryptedFrameFormat, 4);
-
-/**
- * <code>PP_VideoCodec</code> contains video codec type constants.
- */
-typedef enum {
- PP_VIDEOCODEC_UNKNOWN = 0,
- PP_VIDEOCODEC_VP8 = 1
-} PP_VideoCodec;
-PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_VideoCodec, 4);
+ PP_STREAMTYPE_UNKNOWN = 0,
+ PP_STREAMTYPE_AUDIO = 1,
+ PP_STREAMTYPE_VIDEO = 2
+} PP_StreamType;
+PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_StreamType, 4);
/**
* @}
*/
@@ -156,34 +146,26 @@ PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_VideoCodec, 4);
* @{
*/
/**
- * <code>PP_EncryptedVideoFrameInfo</code> contains the information required
- * to decrypt and decode a video frame.
- * TODO(tomfinegan): Revisit necessity of including format information in this
- * struct once we decide how to implement video decoder initialization.
+ * <code>PP_EncryptedMediaInfo</code> contains the information required to
+ * decrypt and decode media data.
*/
-struct PP_EncryptedVideoFrameInfo {
+struct PP_EncryptedMediaInfo {
/**
- * The decoded video frame format.
+ * Media type of the encrypted data.
*/
- PP_DecryptedFrameFormat format;
+ PP_StreamType media_type;
/**
- * The video frame codec type.
- */
- PP_VideoCodec codec;
- /**
- * Video frame width in pixels.
- */
- int32_t width;
- /**
- * Video frame height in pixels.
+ * 4-byte padding to make the size of <code>PP_EncryptedMediaInfo</code>
+ * a multiple of 8 bytes and make sure |encryption_info| starts on an 8-byte
+ * boundary. The value of this field should not be used.
*/
- int32_t height;
+ uint32_t padding;
/**
* Information required to decrypt the frame.
*/
struct PP_EncryptedBlockInfo encryption_info;
};
-PP_COMPILE_ASSERT_STRUCT_SIZE_IN_BYTES(PP_EncryptedVideoFrameInfo, 256);
+PP_COMPILE_ASSERT_STRUCT_SIZE_IN_BYTES(PP_EncryptedMediaInfo, 248);
/**
* @}
*/
@@ -193,6 +175,26 @@ PP_COMPILE_ASSERT_STRUCT_SIZE_IN_BYTES(PP_EncryptedVideoFrameInfo, 256);
* @{
*/
/**
+ * <code>PP_DecryptedFrameFormat</code> contains video frame formats.
+ */
+typedef enum {
+ PP_DECRYPTEDFRAMEFORMAT_UNKNOWN = 0,
+ PP_DECRYPTEDFRAMEFORMAT_EMPTY = 1,
+ PP_DECRYPTEDFRAMEFORMAT_YV12 = 2,
+ PP_DECRYPTEDFRAMEFORMAT_I420 = 3
+} PP_DecryptedFrameFormat;
+PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_DecryptedFrameFormat, 4);
+
+/**
+ * <code>PP_VideoCodec</code> contains video codec type constants.
+ */
+typedef enum {
+ PP_VIDEOCODEC_UNKNOWN = 0,
+ PP_VIDEOCODEC_VP8 = 1
+} PP_VideoCodec;
+PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_VideoCodec, 4);
+
+/**
* The <code>PP_DecryptResult</code> enum contains decryption and decoding
* result constants.
*/
@@ -156,34 +146,26 @@ PP_COMPILE_ASSERT_SIZE_IN_BYTES(PP_VideoCodec, 4);
/**
- * Information required to decrypt the frame.
+ * Information required to decrypt the media.
*/
struct PP_EncryptedBlockInfo encryption_info;

Powered by Google App Engine
This is Rietveld 408576698